API Reference
=============

This is the API reference for the pyspotify project. It is
structured similarly to the `libspotify API documentation
<http://developer.spotify.com/en/libspotify/docs/>`_.

.. module:: spotify

All the classes and submodules of pyspotify are contained in the :mod:`spotify`
parent module.

.. toctree::

    error
    session
    link
    track
    album
    artist
    albumbrowse
    artistbrowse
    image
    search
    playlist
    container
    user
    toplist
    inbox
    constants
